from django.conf.urls import url
from django.utils.html import format_html
from django.contrib.staticfiles.templatetags.staticfiles import static
from wagtail.wagtailcore import hooks
from wagtail.wagtailadmin.menu import MenuItem


@hooks.register('insert_global_admin_css')
def global_admin_css():
    html = '<link rel="stylesheet" href="{path}">'.format(path=static('css/wagtail_uplift.min.css'))
    return format_html(html)

@hooks.register('register_admin_menu_item')
def register_tile_menu_item():
    return MenuItem(
        'Pages',
        '/cmsadmin/pages/',
        classnames='icon icon-folder-open-1',
        order=1)

@hooks.register('construct_main_menu')
def hide_explorer_menu_item(request, menu_items):
    menu_items[:] = [item for item in menu_items if item.name != 'explorer']



# -*- coding: utf-8 -*-
from setuptools import find_packages, setup


setup(
    name='wagtail_uplift',
    version='0.0.8',
    packages=find_packages(),
    include_package_data=True,
    license='BSD License',
    description='A custom theme for Wagtail’s dashboard.',
    long_description=open('README.rst').read(),
    url='https://github.com/l1f7/wagtail_uplift',
    author='Lift Interactive',
    author_email='dev+pypi@liftinteractive.com',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Framework :: Django',
        'Framework :: Django :: 1.8',
        'Framework :: Django :: 1.9',
        'Topic :: Internet :: WWW/HTTP :: Site Management',
    ],
)
